@@ -167,7 +167,7 @@ class __EXPORT IPV4Cidr
 protected:
 	struct in_addr netmask, network;
 
-	unsigned getMask(const char *cp);
+	unsigned getMask(const char *cp) const;
 public:
 	/**
 	 * Get network address associated with this cidr.
@@ -225,7 +225,7 @@ public:
 	 * @param saddr pointer to test.
 	 * @return true if member of cidr.
 	 */
-	bool isMember(struct sockaddr *saddr);
+	bool isMember(const struct sockaddr *saddr) const;
 
 	/**
 	 * See if a low level address object is a member of this cidr's net.
@@ -233,15 +233,15 @@ public:
 	 * @param inaddr object to test.
 	 * @return true if member of cidr.
 	 */
-	bool isMember(struct in_addr &inaddr);
+	bool isMember(const struct in_addr &inaddr) const;
+
+	inline bool operator==(const struct sockaddr *a) const
+		{return isMember(a);};
+
+	inline bool operator==(const struct in_addr &a) const
+		{return isMember(a);};
 };
 
-inline bool operator==(struct sockaddr *sa, IPV4Cidr &cidr)
-	{return cidr.isMember(sa);};
-
-inline bool operator==(struct in_addr &a, IPV4Cidr &cidr)
-	{return cidr.isMember(a);};
-
 #ifdef	CCXX_IPV6
 /**
  * The CIDR class is used to support routing tables and validate address
@@ -255,7 +255,7 @@ class __EXPORT IPV6Cidr
 protected:
 	struct in6_addr netmask, network;
 
-	unsigned getMask(const char *cp);
+	unsigned getMask(const char *cp) const;
 public:
 	/**
 	 * Get network address associated with this cidr.
@@ -313,7 +313,7 @@ public:
 	 * @param saddr pointer to test.
 	 * @return true if member of cidr.
 	 */
-	bool isMember(struct sockaddr *saddr);
+	bool isMember(const struct sockaddr *saddr) const;
 
 	/**
 	 * See if a low level address object is a member of this cidr's net.
@@ -321,15 +321,15 @@ public:
 	 * @param inaddr object to test.
 	 * @return true if member of cidr.
 	 */
-	bool isMember(struct in6_addr &inaddr);
+	bool isMember(const struct in6_addr &inaddr) const;
+
+	inline bool operator==(const struct sockaddr *sa) const
+		{return isMember(sa);};
+
+	inline bool operator==(const struct in6_addr &a) const
+		{return isMember(a);};
 };
 
-inline bool operator==(struct sockaddr *sa, IPV6Cidr &cidr)
-	{return cidr.isMember(sa);};
-
-inline bool operator==(struct in6_addr &a, IPV6Cidr &cidr)
-	{return cidr.isMember(a);};
-
 #endif
 
 /**
