@@ -695,7 +695,7 @@ protected:
 	virtual void *getMemory(size_t size) = 0;
 
 public:
-	void *getPointer(const char *id);
+	void *getPointer(const char *id) const;
 	void setPointer(const char *id, void *data);
 };
 
