@@ -1410,14 +1410,14 @@ public:
 	 * 
 	 * @return true if the thread is still executing.
 	 */
-	bool isRunning(void);
+	bool isRunning(void) const;
 
 	/**
 	 * Check if this thread is detached.
 	 *
 	 * @return true if the thread is detached.
 	 */
-	bool isDetached(void);
+	bool isDetached(void) const;
 
         /**
 	 * Blocking call which unlocks when thread terminates.
@@ -1430,7 +1430,7 @@ public:
 	 * 
 	 * @return true if the current context is this object.
 	 */
-	bool isThread(void);
+	bool isThread(void) const;
 
 	/**
 	 * Get system thread numeric identifier.
@@ -1445,7 +1445,7 @@ public:
 	 *
 	 * @return debug name.
 	 */
-	const char *getName(void)
+	const char *getName(void) const
 		{return _name;};
 
 	/**
@@ -1475,7 +1475,7 @@ public:
 		{if (th._start) th._start->wait();};
 
 #ifdef WIN32
-	bool isCancelled();
+	bool isCancelled() const;
 
 	static DWORD waitThread(HANDLE hRef, timeout_t timeout);
 #endif
