@@ -787,7 +787,7 @@ void Thread::notify(Thread *)
 {
 }
 
-bool Thread::isThread(void)
+bool Thread::isThread(void) const
 {
 	if(!priv)
 		return false;
@@ -799,7 +799,7 @@ bool Thread::isThread(void)
 #endif
 }
 
-bool Thread::isDetached(void)
+bool Thread::isDetached(void) const
 {
         if(!priv)
                 return false;
@@ -820,12 +820,12 @@ bool Thread::isDetached(void)
 cctid_t Thread::getId(void) const
 {
 	if(!priv)
-		return -1;
+		return (cctid_t)-1;
 
 	return priv->_tid;
 }
 
-bool Thread::isRunning(void)
+bool Thread::isRunning(void) const
 {
 	if(!priv)
 		return false;
@@ -1335,7 +1335,7 @@ bool Thread::testCancel(void)
 
 #ifdef WIN32
 
-bool Thread::isCancelled()
+bool Thread::isCancelled() const
 {
 	return waitThread(priv->_cancellation, 0) == WAIT_OBJECT_0;
 }
